@@ -44,18 +44,12 @@ static void     gpm_engine_finalize   (GObject	  *object);
 #define GPM_ENGINE_WARN_ACCURACY	20
 #define GPM_USE_COMPOSITE		0
 
-/* Left to convert:
- * 1. Recall data
- */
-
 struct GpmEnginePrivate
 {
 	GConfClient		*conf;
 	DkpClient		*client;
-	GPtrArray		*array;
-#if GPM_USE_COMPOSITE
 	DkpDevice		*battery_composite;
-#endif
+	GPtrArray		*array;
 	GpmPhone		*phone;
 	GpmIconPolicy		 icon_policy;
 	gchar			*previous_icon;
@@ -90,6 +84,8 @@ static gpointer gpm_engine_object = NULL;
 
 G_DEFINE_TYPE (GpmEngine, gpm_engine, G_TYPE_OBJECT)
 
+static DkpDevice *gpm_engine_update_composite_device (GpmEngine *engine, DkpDevice *original_device);
+
 typedef enum {
 	GPM_ENGINE_WARNING_NONE = 0,
 	GPM_ENGINE_WARNING_DISCHARGING = 1,
@@ -292,6 +288,10 @@ gpm_engine_get_icon_priv (GpmEngine *engine, DkpDeviceType device_type, GpmEngin
 			      "is-present", &is_present,
 			      NULL);
 
+		/* if battery then use composite device to cope with multiple batteries */
+		if (type == DKP_DEVICE_TYPE_BATTERY)
+			device = gpm_engine_update_composite_device (engine, device);
+
 		warning_temp = GPOINTER_TO_INT(g_object_get_data (G_OBJECT(device), "engine-warning-old"));
 		if (type == device_type && is_present) {
 			if (warning != GPM_ENGINE_WARNING_NONE) {
@@ -520,7 +520,16 @@ gpm_engine_device_check_capacity (GpmEngine *engine, DkpDevice *device)
 		      "capacity", &capacity,
 		      NULL);
 
-	if (type != DKP_DEVICE_TYPE_BATTERY || capacity > 50.0f)
+	/* not laptop battery */
+	if (type != DKP_DEVICE_TYPE_BATTERY)
+		return FALSE;
+
+	/* capacity okay */
+	if (capacity > 50.0f)
+		return FALSE;
+
+	/* capacity invalid */
+	if (capacity < 1.0f)
 		return FALSE;
 
 	/* only emit this if specified in gconf */
@@ -532,20 +541,22 @@ gpm_engine_device_check_capacity (GpmEngine *engine, DkpDevice *device)
 	return TRUE;
 }
 
-#if GPM_USE_COMPOSITE
 /**
  * gpm_engine_update_composite_device:
  **/
 static DkpDevice *
-gpm_engine_update_composite_device (GpmEngine *engine)
+gpm_engine_update_composite_device (GpmEngine *engine, DkpDevice *original_device)
 {
 	guint i;
+	gdouble percentage;
+	gdouble energy;
+	gdouble energy_full;
+	gdouble energy_rate;
+	gdouble energy_total = 0.0;
+	gdouble energy_full_total = 0.0;
+	gdouble energy_rate_total = 0.0;
 	gint64 time_to_empty = 0;
-	gint64 time_to_empty_total = 0;
 	gint64 time_to_full = 0;
-	gint64 time_to_full_total = 0;
-	gdouble percentage = 0;
-	gdouble percentage_total = 0;
 	guint battery_devices = 0;
 	gboolean is_charging = FALSE;
 	gboolean is_discharging = FALSE;
@@ -554,6 +565,10 @@ gpm_engine_update_composite_device (GpmEngine *engine)
 	DkpDevice *device;
 	DkpDeviceState state;
 	DkpDeviceType type;
+	gboolean debug;
+
+	/* are we printing to console? */
+	debug = egg_debug_enabled ();
 
 	/* update the composite device */
 	array = engine->priv->array;
@@ -561,16 +576,18 @@ gpm_engine_update_composite_device (GpmEngine *engine)
 		device = g_ptr_array_index (engine->priv->array, i);
 		g_object_get (device,
 			      "type", &type,
-			      "time-to-empty", &time_to_empty,
-			      "time-to-full", &time_to_full,
-			      "percentage", &percentage,
 			      "state", &state,
+			      "energy", &energy,
+			      "energy-full", &energy_full,
+			      "energy-rate", &energy_rate,
 			      NULL);
 		if (type != DKP_DEVICE_TYPE_BATTERY)
 			continue;
 
-		egg_debug ("printing device %i", i);
-		dkp_device_print (device);
+		if (debug) {
+			egg_debug ("printing device %i", i);
+			dkp_device_print (device);
+		}
 
 		/* one of these will be charging or discharging */
 		if (state == DKP_DEVICE_STATE_CHARGING)
@@ -579,15 +596,23 @@ gpm_engine_update_composite_device (GpmEngine *engine)
 			is_discharging = TRUE;
 		if (state == DKP_DEVICE_STATE_FULLY_CHARGED)
 			is_fully_charged = TRUE;
-		time_to_empty_total += time_to_empty;
-		time_to_full_total += time_to_full;
-		percentage_total += percentage;
+
+		/* sum up composite */
+		energy_total += energy;
+		energy_full_total += energy_full;
+		energy_rate_total += energy_rate;
 		battery_devices++;
 	}
 
-	/* use average percentage */
-	if (battery_devices > 0)
-		percentage_total /= battery_devices;
+	/* just use the original device if only one primary battery */
+	if (battery_devices == 1) {
+		egg_debug ("using original device as only one primary battery");
+		device = original_device;
+		goto out;
+	}
+
+	/* use percentage weighted for each battery capacity */
+	percentage = 100.0 * energy_total / energy_full_total;
 
 	/* set composite state */
 	if (is_charging)
@@ -599,19 +624,32 @@ gpm_engine_update_composite_device (GpmEngine *engine)
 	else
 		state = DKP_DEVICE_STATE_UNKNOWN;
 
+	/* calculate a quick and dirty time remaining value */
+	if (energy_rate_total > 0) {
+		if (state == DKP_DEVICE_STATE_DISCHARGING)
+			time_to_empty = 3600 * (energy_total / energy_rate_total);
+		else if (state == DKP_DEVICE_STATE_CHARGING)
+			time_to_full = 3600 * ((energy_full_total - energy_total) / energy_rate_total);
+	}
+
+	/* okay, we can use the composite device */
+	device = engine->priv->battery_composite;
+
 	egg_debug ("printing composite device");
-	g_object_set (engine->priv->battery_composite,
-		      "time-to-empty", time_to_empty_total,
-		      "time-to-full", time_to_full_total,
-		      "percentage", percentage_total,
+	g_object_set (device,
+		      "energy", energy,
+		      "energy-full", energy_full,
+		      "energy-rate", energy_rate,
+		      "time-to-empty", time_to_empty,
+		      "time-to-full", time_to_full,
+		      "percentage", percentage,
 		      "state", state,
 		      NULL);
-	dkp_device_print (engine->priv->battery_composite);
-
-	/* return set composite device */
-	return engine->priv->battery_composite;
+	dkp_device_print (device);
+out:
+	/* return composite device or original device */
+	return device;
 }
-#endif
 
 /**
  * gpm_engine_device_add:
@@ -622,9 +660,7 @@ gpm_engine_device_add (GpmEngine *engine, DkpDevice *device)
 	GpmEngineWarning warning;
 	DkpDeviceState state;
 	DkpDeviceType type;
-#if GPM_USE_COMPOSITE
 	DkpDevice *composite;
-#endif
 
 	/* assign warning */
 	warning = gpm_engine_get_warning (engine, device);
@@ -640,11 +676,11 @@ gpm_engine_device_add (GpmEngine *engine, DkpDevice *device)
 		      NULL);
 
 	/* add old state for transitions */
+	egg_debug ("adding %s with state %s", dkp_device_get_object_path (device), dkp_device_state_to_text (state));
 	g_object_set_data (G_OBJECT(device), "engine-state-old", GUINT_TO_POINTER(state));
 
-#if GPM_USE_COMPOSITE
 	if (type == DKP_DEVICE_TYPE_BATTERY) {
-		composite = gpm_engine_update_composite_device (engine);
+		composite = gpm_engine_update_composite_device (engine, device);
 
 		/* get the same values for the composite device */
 		warning = gpm_engine_get_warning (engine, composite);
@@ -652,7 +688,44 @@ gpm_engine_device_add (GpmEngine *engine, DkpDevice *device)
 		g_object_get (composite, "state", &state, NULL);
 		g_object_set_data (G_OBJECT(composite), "engine-state-old", GUINT_TO_POINTER(state));
 	}
+}
+
+/**
+ * gpm_engine_check_recall:
+ **/
+static gboolean
+gpm_engine_check_recall (GpmEngine *engine, DkpDevice *device)
+{
+	DkpDeviceType type;
+	gboolean recall_notice = FALSE;
+	gchar *recall_vendor = NULL;
+	gchar *recall_url = NULL;
+
+	/* get device properties */
+	g_object_get (device,
+		      "type", &type,
+#if DKP_CHECK_VERSION(0x009)
+		      "recall-notice", &recall_notice,
+		      "recall-vendor", &recall_vendor,
+		      "recall-url", &recall_url,
 #endif
+		      NULL);
+
+	/* not battery */
+	if (type != DKP_DEVICE_TYPE_BATTERY)
+		goto out;
+
+	/* no recall data */
+	if (!recall_notice)
+		goto out;
+
+	/* emit signal for manager */
+	egg_debug ("** EMIT: perhaps-recall");
+	g_signal_emit (engine, signals [PERHAPS_RECALL], 0, device, recall_vendor, recall_url);
+out:
+	g_free (recall_vendor);
+	g_free (recall_url);
+	return recall_notice;
 }
 
 /**
@@ -708,6 +781,7 @@ gpm_engine_coldplug_idle_cb (GpmEngine *engine)
 	for (i=0;i<array->len;i++) {
 		device = g_ptr_array_index (engine->priv->array, i);
 		gpm_engine_device_add (engine, device);
+		gpm_engine_check_recall (engine, device);
 	}
 
 	/* never repeat */
@@ -722,6 +796,7 @@ gpm_engine_device_added_cb (DkpClient *client, DkpDevice *device, GpmEngine *eng
 {
 	/* add to list */
 	g_ptr_array_add (engine->priv->array, g_object_ref (device));
+	gpm_engine_check_recall (engine, device);
 
 	gpm_engine_recalculate_state (engine);
 }
@@ -740,6 +815,7 @@ gpm_engine_device_removed_cb (DkpClient *client, DkpDevice *device, GpmEngine *e
 	gpm_engine_recalculate_state (engine);
 }
 
+
 /**
  * gpm_engine_device_changed_cb:
  **/
@@ -758,6 +834,8 @@ gpm_engine_device_changed_cb (DkpClient *client, DkpDevice *device, GpmEngine *e
 		      "state", &state,
 		      NULL);
 
+	egg_debug ("%s state is now %s", dkp_device_get_object_path (device), dkp_device_state_to_text (state));
+
 	/* see if any interesting state changes have happened */
 	state_old = GPOINTER_TO_INT(g_object_get_data (G_OBJECT(device), "engine-state-old"));
 	if (state_old != state) {
@@ -773,11 +851,9 @@ gpm_engine_device_changed_cb (DkpClient *client, DkpDevice *device, GpmEngine *e
 		g_object_set_data (G_OBJECT(device), "engine-state-old", GUINT_TO_POINTER(state));
 	}
 
-#if GPM_USE_COMPOSITE
 	/* if battery then use composite device to cope with multiple batteries */
 	if (type == DKP_DEVICE_TYPE_BATTERY)
-		device = gpm_engine_update_composite_device (engine);
-#endif
+		device = gpm_engine_update_composite_device (engine, device);
 
 	/* check the warning state has not changed */
 	warning_old = GPOINTER_TO_INT(g_object_get_data (G_OBJECT(device), "engine-warning-old"));
@@ -945,16 +1021,15 @@ gpm_engine_init (GpmEngine *engine)
 	g_signal_connect (engine->priv->phone, "device-refresh",
 			  G_CALLBACK (phone_device_refresh_cb), engine);
 
-#if GPM_USE_COMPOSITE
 	/* create a fake virtual composite battery */
 	engine->priv->battery_composite = dkp_device_new ();
 	g_object_set (engine->priv->battery_composite,
 		      "type", DKP_DEVICE_TYPE_BATTERY,
 		      "is-rechargeable", TRUE,
 		      "native-path", "dummy:composite_battery",
+		      "power-supply", TRUE,
 		      "is-present", TRUE,
 		      NULL);
-#endif
 
 	engine->priv->previous_icon = NULL;
 	engine->priv->previous_summary = NULL;
@@ -1081,9 +1156,7 @@ gpm_engine_finalize (GObject *object)
 
 	g_object_unref (engine->priv->client);
 	g_object_unref (engine->priv->phone);
-#if GPM_USE_COMPOSITE
 	g_object_unref (engine->priv->battery_composite);
-#endif
 
 	g_free (engine->priv->previous_icon);
 	g_free (engine->priv->previous_summary);
